using Microwave.Classes.Boundary;
using Microwave.Classes.Boundary.Interfaces;
using NSubstitute;

namespace Microwave.Classes.Test.BoundaryTest;

[TestFixture]
public class TimerTest
{
    private Boundary.Timer _uut;

    [SetUp]
    public void Setup()
    {
        _uut = new Boundary.Timer();
    }

    [Test]
    public void Start_TimerStarted_TimeRemainingSet()
    {
        // Arrange
        int time = 60;

        // Act
        _uut.Start(time);

        // Assert
        Assert.That(_uut.TimeRemaining, Is.EqualTo(time));
    }

    [Test]
    public void Stop_TimerStopped_TimeRemainingUnchanged()
    {
        // Arrange
        int time = 60;
        _uut.Start(time);

        // Act
        _uut.Stop();

        // Assert
        Assert.That(_uut.TimeRemaining, Is.EqualTo(time));
    }

    [Test]
    public void AddTime_TimeAdded_TimeRemainingIncreased()
    {
        // Arrange
        int initialTime = 30;
        _uut.Start(initialTime);

        // Act
        _uut.AddTime();

        // Assert
        Assert.That(_uut.TimeRemaining, Is.EqualTo(initialTime + 30));
    }

    [Test]
    public void TimerTick_EventTriggered_TimerTickHandlerCalled()
    {
        // Arrange
        int notifications = 0;
        _uut.TimerTick += (sender, args) => notifications++;
        _uut.Start(2);

        // Act
        Thread.Sleep(2100); // Wait for 2 ticks

        // Assert
        Assert.That(notifications, Is.EqualTo(2));
    }

    [Test]
    public void Expire_EventTriggered_ExpiredHandlerCalled()
    {
        // Arrange
        int notifications = 0;
        _uut.Expired += (sender, args) => notifications++;
        _uut.Start(1);

        // Act
        Thread.Sleep(1100); // Wait for timer to expire

        // Assert
        Assert.That(notifications, Is.EqualTo(1));
    }
}
