﻿using System;
using Microwave.Classes.Boundary.Interfaces;

namespace Microwave.Classes.Boundary
{
    public class PowerTube : IPowerTube
    {
        private IOutput myOutput;

        private readonly int maxPower;

        private bool IsOn = false;

        public PowerTube(IOutput output, int MaxPower)
        {
            myOutput = output;

            // Error handling to ensure MaxPower is a multiple of 50
            // Should ensure no rounding errors
            // TODO: Add a test for this
            if (MaxPower % 50 != 0)
            {
                throw new ArgumentOutOfRangeException(
                    "MaxPower",
                    MaxPower,
                    $"Must be a multiple of 50"
                );
            }

            // Error handling to limit MaxPower within correct range
            // TODO: Add a test for this
            if (MaxPower < 400 || MaxPower > 1200)
            {
                throw new ArgumentOutOfRangeException(
                    "MaxPower",
                    MaxPower,
                    $"Must be between 400 and 1200 Watts (incl.)"
                );
            }

            maxPower = MaxPower;
        }

        public void TurnOn(int power)
        {
            if (power < 1 || maxPower < power)
            {
                throw new ArgumentOutOfRangeException(
                    "power",
                    power,
                    $"Must be between 1 and {maxPower} (incl.)" // TODO: Add a test for this part. Dynamic error message, make sure its working.
                );
            }

            if (IsOn)
            {
                throw new ApplicationException("PowerTube.TurnOn: is already on");
            }

            myOutput.OutputLine($"PowerTube works with {power}");
            IsOn = true;
        }

        public int GetMaxPower() // TODO: Add a test for this method
        {
            return maxPower;
        }

        public void TurnOff()
        {
            if (IsOn)
            {
                myOutput.OutputLine($"PowerTube turned off");
            }

            IsOn = false;
        }
    }
}
