﻿﻿using Microwave.Classes.Boundary;
using Microwave.Classes.Controllers;
using Microwave.Classes.Domain;

var startCancelButton = new Button();
var powerButton = new Button();
var timeButton = new Button();

var door = new Door();

var output = new Output();

var buzzer = new Buzzer(output);

var display = new Display(output);

var powerTube = new PowerTube(output, 450); // TODO: Handle cases where the max power is not an equal multiple of 50

var light = new Light(output);

var timer = new Timer();

var cooker = new CookController(timer, display, powerTube);

var ui = new MicrowaveController(
    powerButton,
    timeButton,
    startCancelButton,
    door,
    display,
    light,
    cooker,
    buzzer
);

// Finish the double association
cooker.Microwave = ui;

// Simulate a button press loop
while (true)
{
    System.Console.WriteLine(
        "Press 'p' for Power, 't' for Time, 's' for Start/Cancel, or 'q' to quit:"
    );
    var input = System.Console.ReadLine();

    if (string.IsNullOrEmpty(input))
        break;

    switch (input.ToLower())
    {
        case "p":
            powerButton.Press();
            break;
        case "t":
            timeButton.Press();
            break;
        case "s":
            startCancelButton.Press();
            break;
        case "q":
            System.Console.WriteLine("Exiting program...");
            return;
        default:
            System.Console.WriteLine("Invalid input. Try again.");
            break;
    }
}
